function vrwmScan1_prepare_fcn(object,event)

userdata=object.userdata;

w=userdata.w;
v=userdata.v;
t=userdata.t;
maxFramesLow=userdata.maxFramesLow;
maxFramesHigh=userdata.maxFramesHigh;
rootFolder=userdata.rootFolder;
mapFolder=userdata.mapFolder;

% load parameter file
parameters=readFile('','parametersScan1.txt');

subCode = parameters.subCode;
groupName=parameters.groupName;
runNr = parameters.blockNum;
nrTrials = parameters.nrTrials;
nrStartPos = parameters.nrStartPos;
radius = parameters.radius;
range = parameters.range;
pfSize = parameters.pfSize;

% platform position array
pfXNovel = 999; % initial to values which can't be found in the search area
pfYNovel = 999;
pfIterNovel = 1;

% load required nodes for the next section
cam=vrnode(w,'Camera');
platform=vrnode(w,'platform_tran');
wallOneTexture=vrnode(w,'wallOneTexture');
wallTwoTexture=vrnode(w,'wallTwoTexture');
wallThreeTexture=vrnode(w,'wallThreeTexture');
wallFourTexture=vrnode(w,'wallFourTexture');
feedbackTran1=vrnode(w,'feedbackTran1');
feedbackTran2=vrnode(w,'feedbackTran2');
textMessage1=vrnode(w,'textMessage1');
textMessage2=vrnode(w,'textMessage2');
fixationCross=vrnode(w,'fixationCross');

% create novel cue wall array
cueWallArray = randperm(parameters.nrPossibleCueWalls)';
cueWallArray = cueWallArray(cueWallArray>1);

% search walls
fixedCueWall=[mapFolder 'greyCueTrain.jpg'];
novelCueWall=[mapFolder 'greyCue' num2str(cueWallArray(pfIterNovel)) '.jpg'];
blankWall1=[mapFolder 'grey.jpg'];
blankWall2=[mapFolder 'grey.jpg'];
% timeout wall
timeOutWall=[mapFolder 'red.jpg'];
successWall=[mapFolder 'green.jpg'];
predictErrorWall=[mapFolder 'orange.jpg'];

wallOneTexture.url=fixedCueWall;
wallTwoTexture.url=blankWall2;
wallThreeTexture.url=blankWall1;
wallFourTexture.url=blankWall2;

% calculate trial start positions and directions
angIncrement = (2*pi)/nrStartPos;
trialOrderArray1 = [];
trialOrderArray2 = [];
for i = 1:nrTrials/nrStartPos
    trialOrderArray1 = [trialOrderArray1; randperm(nrStartPos)'];
    trialOrderArray2 = [trialOrderArray2; randperm(nrStartPos)'];
end
trialAngArray1 = (trialOrderArray1*angIncrement)-angIncrement;
trialAngArray2 = (trialOrderArray2*angIncrement)-angIncrement;
multFactor = (rand(nrTrials,1)-0.5)*2;
dirOver = trialAngArray1+(multFactor*(range*(pi/180)));
dirNovel = trialAngArray2+(multFactor*(range*(pi/180)));
xCoordOver = (radius-.35)*cos(dirOver);
xCoordNovel = (radius-.35)*cos(dirNovel);
yCoordOver = (radius-.35)*sin(dirOver);
yCoordNovel = (radius-.35)*sin(dirNovel);

% determine novel target zone (-4 to 4)
a = randperm(9);
b = a(a~=5);
c = b-5;
d = c(1,ceil(rand*8));

if d > 0
    novelTargetZoneHigh = d*(pi/4);
    novelTargetZoneLow = (d*(pi/4))-(pi/4);
elseif d < 0
    novelTargetZoneLow = d*(pi/4);
    novelTargetZoneHigh = (d*(pi/4))+(pi/4);
end
    

delayFrames = (rand*4)*parameters.SR;
maxNovelRadius = (rand*3+3.5);

% updata userdata of waitTimer
object.userdata=userdata;

% prepare data needed during evaluation
data.trial=0;
data.i=0;
data.frameNumIter=0;
data.xyPath=zeros(maxFramesHigh,3);
data.frameNumStore=zeros(maxFramesHigh,1);
data.trialStateStore=zeros(maxFramesHigh,1);
data.trialStore=zeros(maxFramesHigh,1);
data.pulseReg=zeros(maxFramesHigh,1);
data.aPress=zeros(maxFramesHigh,1);
data.waitTimer=object;
data.trialState=3;
data.pfFrame=0;
data.spIterOver=0;
data.spIterNovel=0;
data.pfIterNovel=pfIterNovel;
data.pfIterFindCount=0;
data.holdState=0;
data.noTimeOut=0;
data.probePhase=1;
data.probePhaseOneComplete=0;
data.endRun=0;
data.restPause=175;
data.trialType=1;
data.currentTrialType=1;
data.pressNr=0;
data.endPress=0;
data.redGuessWall = 0;
data.redGuessWallTime = 0;
data.initialiseNovelPf1 = 0;
data.initialiseNovelPf2 = 0;
data.entryFrameNum = 0;
data.novelPfSet = 0;

% pass on nodes required during trial
nodes.cam=cam;
nodes.platform=platform;
nodes.wallOneTexture=wallOneTexture;
nodes.wallTwoTexture=wallTwoTexture;
nodes.wallThreeTexture=wallThreeTexture;
nodes.wallFourTexture=wallFourTexture;
nodes.feedbackTran1=feedbackTran1;
nodes.feedbackTran2=feedbackTran2;
nodes.textMessage1=textMessage1;
nodes.textMessage2=textMessage2;
nodes.fixationCross=fixationCross;

% store environment data
data.w=w;
data.v=v;
data.nodes=nodes;
data.maxFramesLow=maxFramesLow;
data.maxFramesHigh=maxFramesHigh;
data.yCoordOver=yCoordOver;
data.xCoordOver=xCoordOver;
data.dirOver=dirOver;
data.yCoordNovel=yCoordNovel;
data.xCoordNovel=xCoordNovel;
data.dirNovel=dirNovel;
data.runNr=runNr;
data.trialOrderArray1=trialOrderArray1;
data.trialOrderArray2=trialOrderArray2;
data.pfXOver=parameters.pfXOver;
data.pfYOver=parameters.pfYOver;
data.pfXNovel=pfXNovel;
data.pfYNovel=pfYNovel;
data.keySetup=parameters.keySetup;
data.posStep=parameters.posStep;
data.rotStep=parameters.rotStep;
data.radius=parameters.radius;
data.pfSize=parameters.pfSize;
data.pfPause=parameters.pfPause;
data.SR=parameters.SR;
data.timeOutPause=parameters.timeOutPause;
data.maxTrialLength=parameters.maxTrialLength*parameters.SR;
data.nrTrials=parameters.nrTrials;
data.rootFolder=rootFolder;
data.novelCueWall=novelCueWall;
data.fixedCueWall=fixedCueWall;
data.blankWall1=blankWall1;
data.blankWall2=blankWall2;
data.timeOutWall=timeOutWall;
data.successWall=successWall;
data.predictErrorWall=predictErrorWall;
data.keysAtOnce=parameters.keysAtOnce;
data.subCode=subCode;
data.groupName=groupName;
data.restPauseLow=parameters.restPauseLow;
data.restPauseHigh=parameters.restPauseHigh;
data.feedbackPause=round(parameters.feedbackPause*parameters.SR);
data.cuePause=round(parameters.cuePause*parameters.SR);
data.mapFolder=mapFolder;
data.novelTargetZoneHigh=novelTargetZoneHigh;
data.novelTargetZoneLow=novelTargetZoneLow;
data.delayFrames=delayFrames;
data.maxNovelRadius=maxNovelRadius;

% store data in userdata of trialTimer
t.userdata=data;

breakLoop=0;
for l = 1:10000000

    [pressed b check]=KbCheck;

    if pressed==1
        keys=find(check==1);
        for k=1:length(keys)
            if keys(k)== 84  % when trigger is sent
                breakLoop = 1;
            end
        end
    end

    if breakLoop == 1
        break
    end

end

% remove previous feedback
feedbackTran1.translation=[0 -150 -.25];

% set position and orientation
cam.position=[0 -100 0];
cam.orientation=[0 1 0 0];
fixationCross.translation=[0 -100 -.25];
fixationCross.rotation=[0 1 0 0];

% stop this script
stop(object)
% start trial
start(t)